@@ -4,7 +4,7 @@
 #include "osl/record/kakinoki.h"
 #include "osl/record/record.h"
 #include "osl/record/ki2.h"
-#include "osl/record/psn.h"
+#include "osl/usi.h"
 #include <boost/program_options.hpp>
 #include <iostream>
 #include <iomanip>
@@ -14,7 +14,7 @@
 namespace po = boost::program_options;
 using namespace osl;
 
-void analyze_root(const NumEffectState& state, const vector<Move>& moves, int move_number);
+void analyze_root(const NumEffectState& state, const std::vector<Move>& moves, int move_number);
 int main(int argc, char **argv)
 {
   po::options_description options;
@@ -48,21 +48,21 @@ int main(int argc, char **argv)
   }
   if (filename.empty())
     return 1;
-  vector<Move> moves;
+  std::vector<Move> moves;
   NumEffectState state;
   try 
   {
     if (filename.find(".kif") == filename.size()-4) 
     {
       KakinokiFile file(filename);
-      moves = file.getRecord().getMoves();
-      state = file.getRecord().getInitialState();
+      moves = file.moves();
+      state = file.initialState();
     } 
     else if (filename.find(".ki2") == filename.size()-4) 
     {
       Ki2File file(filename);
-      moves = file.getRecord().getMoves();
-      state = file.getRecord().getInitialState();
+      moves = file.moves();
+      state = file.initialState();
     }
   }
   catch (KakinokiIOError&) 
@@ -82,7 +82,7 @@ int main(int argc, char **argv)
   }
 }
 
-void analyze_root(const NumEffectState& src, const vector<Move>& moves, int move_number)
+void analyze_root(const NumEffectState& src, const std::vector<Move>& moves, int move_number)
 {
   std::ostringstream ret;
   ret << "[(" << move_number << ") ";
@@ -91,7 +91,7 @@ void analyze_root(const NumEffectState& src, const vector<Move>& moves, int move
   {
     for (int i=0; i<move_number-1; ++i)
       s.makeMove(moves[i]);
-    ret << record::ki2::show(moves[move_number-1], s) << "]\n";
+    ret << ki2::show(moves[move_number-1], s) << "]\n";
     s.makeMove(moves[move_number-1]);
   }
 
