@@ -1,7 +1,7 @@
 /* printMove.cc
  */
-#include "osl/move.h"
-#include "osl/record/csa.h"
+#include "osl/basic_type.h"
+#include "osl/csa.h"
 #include <iostream>
 
 bool csa_mode = false;
@@ -10,7 +10,7 @@ void show(int move)
 {
     Move m = Move::makeDirect(move);
     if (csa_mode)
-	std::cout << record::csa::show(m) << std::endl;
+	std::cout << csa::show(m) << std::endl;
     else
 	std::cout << m << std::endl;
 }
