@@ -1,6 +1,6 @@
 /* printPiece.cc
  */
-#include "osl/square.h"
+#include "osl/basic_type.h"
 #include <iostream>
 
 using namespace osl;
