@@ -1,6 +1,6 @@
 /* printPtypeO.cc
  */
-#include "osl/ptype.h"
+#include "osl/basic_type.h"
 #include <iostream>
 
 using namespace osl;
