@@ -2,8 +2,7 @@
  */
 
 #include "osl/eval/ppair/piecePairRawEval.h"
-#include "osl/record/csa.h"
-#include <boost/scoped_ptr.hpp>
+#include "osl/csa.h"
 #include <iostream>
 #include <cstdlib>
 #include <cstdio>
@@ -24,10 +23,9 @@ void usage(const char *prog)
 
 void show(std::ostream& os, Square pos, PtypeO ptypeo)
 {
-  csaShow(os, pos);
-  os << " ";
+  os << csa::show(pos) << " ";
   os << getOwner(ptypeo);
-  csaShow(os, getPtype(ptypeo));
+  os << csa::show(getPtype(ptypeo));
 }
 
 int main(int argc, char **argv)
@@ -55,9 +53,9 @@ int main(int argc, char **argv)
   filename1 = argv[0];
   filename2 = argv[1];
 
-  boost::scoped_ptr<PiecePairRawTable> table1(new PiecePairRawTable());
+  std::unique_ptr<PiecePairRawTable> table1(new PiecePairRawTable());
   table1->loadFromBinaryFile(filename1);
-  boost::scoped_ptr<PiecePairRawTable> table2(new PiecePairRawTable());
+  std::unique_ptr<PiecePairRawTable> table2(new PiecePairRawTable());
   table2->loadFromBinaryFile(filename2);
 
   for (unsigned int i=0; i<PiecePairRawTable::maxPairIndex; ++i)
@@ -85,4 +83,5 @@ int main(int argc, char **argv)
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
+// ;;; coding:utf-8
 // ;;; End:
