@@ -170,7 +170,7 @@ int main(int argc, char **argv)
   if (error_flag || (! read_pairfilename) || (! write_pairfilename))
     usage(program_name);
 
-  boost::scoped_ptr<PiecePairRawTable> table(new PiecePairRawTable);
+  std::unique_ptr<PiecePairRawTable> table(new PiecePairRawTable);
   table->loadFromBinaryFile(read_pairfilename);
 
   // 通常の5x5の範囲
