@@ -2,8 +2,7 @@
  */
 
 #include "osl/eval/ppair/piecePairRawEval.h"
-#include "osl/record/csaString.h"
-#include "osl/state/simpleState.h"
+#include "osl/csa.h"
 #include <iostream>
 #include <iomanip>
 #include <cstdlib>
