@@ -3,7 +3,6 @@
 #include "osl/eval/progressEval.h"
 #include "osl/eval/ppair/piecePairPieceEval.h"
 #include "osl/record/csaRecord.h"
-#include "osl/state/numEffectState.h"
 #include "osl/oslConfig.h"
 #include <iostream>
 #include <iomanip>
@@ -79,8 +78,8 @@ void show(const NumEffectState& state)
 void show(const char *filename)
 {
   CsaFile file(filename);
-  const vector<osl::Move> moves = file.getRecord().getMoves();
-  NumEffectState state(file.getInitialState());
+  const auto moves = file.load().moves();
+  NumEffectState state(file.initialState());
   for (unsigned int i=0; i<moves.size(); i++)
   {
     show(state);
