@@ -9,7 +9,6 @@
 #include "osl/eval/progressEval.h"
 #include "osl/container/pieceValues.h"
 #include "osl/record/csaRecord.h"
-#include "osl/state/numEffectState.h"
 #include "osl/oslConfig.h"
 #include <stdexcept>
 #include <iostream>
@@ -72,7 +71,7 @@ int main(int argc, char **argv)
   }
 }
 
-void show(const SimpleState& state, const std::string& eval_type)
+void show(const NumEffectState& state, const std::string& eval_type)
 {
   std::cout << state;
   const progress::Effect5x3 progress((NumEffectState(state)));
@@ -101,8 +100,8 @@ void show(const SimpleState& state, const std::string& eval_type)
 void show(const char *filename, const std::string& eval_type)
 {
   CsaFile file(filename);
-  const vector<osl::Move> moves = file.getRecord().getMoves();
-  NumEffectState state(file.getInitialState());
+  const auto moves = file.load().moves();
+  NumEffectState state(file.initialState());
   for (unsigned int i=0; i<moves.size(); i++)
   {
     if (show_all_states)
