@@ -3,16 +3,14 @@
 #include "osl/game_playing/gameState.h"
 #include "osl/record/kisen.h"
 #include "osl/record/csaRecord.h"
-#include "osl/container/moveVector.h"
 #include "osl/sennichite.h"
 #include <boost/program_options.hpp>
-#include <boost/foreach.hpp>
 #include <iostream>
 #include <cmath>
 namespace po = boost::program_options;
 
 using namespace osl;
-void run(const NumEffectState& initial, const vector<Move>& moves) 
+void run(const NumEffectState& initial, const std::vector<Move>& moves) 
 {
   game_playing::GameState state(initial);
   for (size_t i=0; i<moves.size(); ++i){
@@ -23,13 +21,13 @@ void run(const NumEffectState& initial, const vector<Move>& moves)
       std::cerr << state.state();
       std::cerr << "history ";
       for (size_t j=0; j<=i; ++j)
-	std::cerr << record::csa::show(moves[j]);
+	std::cerr << csa::show(moves[j]);
       std::cerr << "\n";
     }
     if (! loss.empty()) {
       std::cerr << "losing moves ";
-      BOOST_FOREACH(Move m, loss) {
-	std::cerr << record::csa::show(m);
+      for (Move m: loss) {
+	std::cerr << csa::show(m);
       }
       std::cerr << "\n";
     }
@@ -78,16 +76,16 @@ int main(int argc, char **argv) {
     KisenFile kisen(kisen_filename);
     for (size_t i=0; i<kisen.size(); ++i) {
       std::cerr << '.';
-      NumEffectState state(kisen.getInitialState());
-      vector<Move> moves = kisen.getMoves(i);
+      NumEffectState state(kisen.initialState());
+      auto moves = kisen.moves(i);
       run(state, moves);
     }
   }
   for (size_t i=0; i<filenames.size(); ++i) {
     std::cerr << '.';
     CsaFile file(filenames[i].c_str());
-    NumEffectState state(file.getInitialState());
-    vector<Move> moves = file.getRecord().getMoves();
+    NumEffectState state(file.initialState());
+    auto moves = file.load().moves();
     run(state, moves);
   }  
 }
