@@ -3,17 +3,15 @@
 #include "osl/game_playing/gameState.h"
 #include "osl/record/kisen.h"
 #include "osl/record/csaRecord.h"
-#include "osl/container/moveVector.h"
 #include "osl/sennichite.h"
 #include <boost/program_options.hpp>
-#include <boost/foreach.hpp>
 #include <iostream>
 #include <cmath>
 namespace po = boost::program_options;
 
 using namespace osl;
 int count = 0;
-bool run(const NumEffectState& initial, const vector<Move>& moves) 
+bool run(const NumEffectState& initial, const std::vector<Move>& moves) 
 {
   NumEffectState state(initial);
   for (size_t i=0; i<moves.size(); ++i){
@@ -65,8 +63,8 @@ int main(int argc, char **argv) {
     KisenFile kisen(kisen_filename);
     for (size_t i=0; i<kisen.size(); ++i) {
       std::cerr << '.';
-      NumEffectState state(kisen.getInitialState());
-      vector<Move> moves = kisen.getMoves(i);
+      NumEffectState state(kisen.initialState());
+      std::vector<Move> moves = kisen.moves(i);
       if (run(state, moves))
 	std::cout << i << "\n";
     }
@@ -74,8 +72,8 @@ int main(int argc, char **argv) {
   for (size_t i=0; i<filenames.size(); ++i) {
     std::cerr << '.';
     CsaFile file(filenames[i].c_str());
-    NumEffectState state(file.getInitialState());
-    vector<Move> moves = file.getRecord().getMoves();
+    NumEffectState state(file.initialState());
+    auto moves = file.load().moves();
     if (run(state, moves))
       std::cout << filenames[i] << "\n";
   }  
