@@ -1,16 +1,10 @@
 /* legal_moves.cc
  */
-#include "osl/state/numEffectState.h"
-#include "osl/record/csa.h"
+#include "osl/numEffectState.h"
 #include "osl/record/csaRecord.h"
-#include "osl/container/moveVector.h"
-#include "osl/move_generator/legalMoves.h"
-#include "osl/move_action/store.h"
 #include "osl/move_generator/addEffectWithEffect.h"
-#include "osl/move_generator/addEffect_.h"
 #include "osl/search/quiescenceGenerator.tcc"
-#include "osl/checkmate/king8Info.h"
-#include "osl/record/csa.h"
+#include "osl/bits/king8Info.h"
 #include <boost/program_options.hpp>
 #include <iostream>
 using namespace osl;
@@ -69,10 +63,10 @@ int main(int argc, char **argv)
 
   for (size_t i = 0; i < files.size(); ++i)
   {
-    const Record record = CsaFile(files[i]).getRecord();
-    NumEffectState state(record.getInitialState());
-    const vector<Move> moves=record.getMoves();
-    for (vector<Move>::const_iterator p=moves.begin(); p!=moves.end(); ++p)
+    const auto record = CsaFileMinimal(files[i]).load();
+    NumEffectState state(record.initialState());
+    const auto moves=record.moves;
+    for (auto p=moves.begin(); p!=moves.end(); ++p)
     {
       state.makeMove(*p);
     }
@@ -93,7 +87,7 @@ int main(int argc, char **argv)
     }
     else 
     {
-      LegalMoves::generate(state, legal_moves);
+      state.generateLegal(legal_moves);
     }
     if (i > 0)
     {
@@ -103,7 +97,7 @@ int main(int argc, char **argv)
     {
       for (size_t i = 0; i < legal_moves.size(); ++i)
       {
-	std::cout << osl::record::csa::show(legal_moves[i]) << std::endl;
+	std::cout << osl::csa::show(legal_moves[i]) << std::endl;
       }
     }
     else
