@@ -1,10 +1,9 @@
-#include "osl/misc/ncores.h"
-
+#include <thread>
 #include <iostream>
 
 int main(int /*argc*/, char ** /*argv*/)
 {
-  std::cout << "Cores: " << osl::misc::ncores() << std::endl;
+  std::cout << "Cores: " << std::thread::hardware_concurrency() << std::endl;
 
   return 0;
 }
