@@ -1,30 +1,21 @@
 // compare-book.cc
-#include "osl/record/opening/openingBook.h"
-#include "osl/record/compactBoard.h"
-#include "osl/record/csa.h"
+#include "osl/book/openingBook.h"
+#include "osl/csa.h"
 #include "osl/record/kanjiPrint.h"
 #include "osl/search/quiescenceSearch2.h"
 #include "osl/search/quiescenceSearch2.tcc"
 #include "osl/search/simpleHashTable.h"
 #include "osl/eval/pieceEval.h"
-#include "osl/stl/vector.h"
-#include "osl/stl/hash_map.h"
-#include "osl/misc/math.h"
+//#include "osl/misc/math.h"
 #include "osl/search/fixedEval.h"
-#include <boost/shared_ptr.hpp>
 #include <boost/program_options.hpp>
 #include <boost/progress.hpp>
 #include <boost/format.hpp>
+#include <unordered_map>
 #include <iostream>
 #include <deque>
 
-#include "osl/move.h"
-#include "osl/record/csaRecord.h"
-#include "osl/record/record.h"
-#include "osl/state/numEffectState.h"
-#include <boost/shared_ptr.hpp>
-
-typedef std::vector<osl::record::opening::WMove> WMoveContainer;
+typedef std::vector<osl::book::WMove> WMoveContainer;
 
 osl::Player the_player = osl::BLACK;
 std::string dump_mode = "none";
@@ -43,17 +34,17 @@ void printUsage(std::ostream& out,
       << std::endl;
 }
 
-typedef osl::hash_map<osl::HashKey,int> table_t;
-void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector<int>& parents)
+typedef std::unordered_map<osl::HashKey,int,std::hash<osl::HashKey>> table_t;
+void store(osl::book::WeightedBook& book, table_t& table, std::vector<int>& parents)
 {
-  WMoveContainer moves = book.getMoves(book.getStartState());
-  parents.resize(book.getTotalState());
+  WMoveContainer moves = book.moves(book.startState());
+  parents.resize(book.totalState());
   std::fill(parents.begin(), parents.end(), -1);
-  boost::progress_display progress(book.getTotalState());
+  boost::progress_display progress(book.totalState());
 
   typedef std::pair<int, int> state_depth_t;
   std::deque<state_depth_t> stateToVisit;
-  stateToVisit.push_back(state_depth_t(book.getStartState(), 1)); // root is 1
+  stateToVisit.push_back(state_depth_t(book.startState(), 1)); // root is 1
   // depth-1手目からdepth手目のstate。depth手目はまだ指されていない（これか
   // らdepth手目）
 
@@ -67,14 +58,14 @@ void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector
     const int depth      = state_depth.second;
     stateToVisit.pop_front();
     ++progress;
-    assert(parents[stateIndex] >= 0 || stateIndex == book.getStartState());
+    assert(parents[stateIndex] >= 0 || stateIndex == book.startState());
 
     depth_found = std::max(depth_found, depth);
-    WMoveContainer moves = book.getMoves(stateIndex);
+    WMoveContainer moves = book.moves(stateIndex);
     
     // 自分（the_player）の手番では、良い手のみ指す
     // 相手はどんな手を指してくるか分からない
-    std::sort(moves.begin(), moves.end(), osl::record::opening::WMoveWeightMoveSort());
+    std::sort(moves.begin(), moves.end(), osl::book::WMoveWeightMoveSort());
     if ( !moves.empty() &&
           ((the_player == osl::BLACK && depth % 2 == 1) ||
            (the_player == osl::WHITE && depth % 2 == 0)) )
@@ -82,13 +73,13 @@ void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector
       int min = 1;
       if (is_determinate) 
       {
-	min = moves.at(0).getWeight();
+	min = moves.at(0).weight;
 	if (depth <= non_determinate_depth) 
 	{
 	  for (int i=1; i<=std::min(is_determinate, (int)moves.size()-1); ++i) 
 	  {
-	    const int weight = moves.at(i).getWeight();
-	    if ((double)weight < (double)moves.at(i-1).getWeight()*ratio)
+	    const int weight = moves.at(i).weight;
+	    if ((double)weight < (double)moves.at(i-1).weight*ratio)
 	      break;
 	    min = weight;
 	  }
@@ -100,7 +91,7 @@ void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector
       WMoveContainer::iterator each = moves.begin();
       for (; each != moves.end(); ++each)
       {
-        if (each->getWeight() < min)
+        if (each->weight < min)
           break;
       }
       moves.erase(each, moves.end());
@@ -112,19 +103,19 @@ void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector
       continue;
     }
 
-    if (moves[0].getWeight()) {
+    if (moves[0].weight) {
       // not leaf
-      const osl::state::NumEffectState state(book.getBoard(stateIndex));
+      const osl::NumEffectState state(book.board(stateIndex));
       const osl::HashKey key(state);
       table[key] = stateIndex;
     }
 
 
     // recursively search the tree
-    for (std::vector<osl::record::opening::WMove>::const_iterator each = moves.begin();
+    for (std::vector<osl::book::WMove>::const_iterator each = moves.begin();
          each != moves.end(); ++each)
     {
-      const int nextIndex = each->getStateIndex();
+      const int nextIndex = each->stateIndex();
       if (parents[nextIndex] < 0) {
 	parents[nextIndex] = stateIndex;
 	stateToVisit.push_back(state_depth_t(nextIndex, depth+1));
@@ -141,21 +132,21 @@ void store(osl::record::opening::WeightedBook& book, table_t& table, osl::vector
                   % depth_found;
 }
 
-void show_moves(const char *name, osl::record::opening::WeightedBook& book, int node)
+void show_moves(const char *name, osl::book::WeightedBook& book, int node)
 {
-  WMoveContainer moves = book.getMoves(node);  
-  std::sort(moves.begin(), moves.end(), osl::record::opening::WMoveWeightMoveSort());
+  WMoveContainer moves = book.moves(node);  
+  std::sort(moves.begin(), moves.end(), osl::book::WMoveWeightMoveSort());
 
-  if (! moves.empty() && moves[0].getWeight()) {
+  if (! moves.empty() && moves[0].weight) {
     std::cout << name;
     for (size_t i=0; i<moves.size(); ++i) {
-      if (moves[i].getWeight() == 0)
+      if (moves[i].weight == 0)
 	break;
-      const int next_state_index = moves[i].getStateIndex();
-      const int black_win        = book.getBlackWinCount(next_state_index);
-      const int white_win        = book.getWhiteWinCount(next_state_index);
-      std::cout << "  " << osl::record::csa::show(moves[i].getMove())
-		<< "(" << moves[i].getWeight() << "," << black_win << "," << white_win << ")";
+      const int next_state_index = moves[i].stateIndex();
+      const int black_win        = book.blackWinCount(next_state_index);
+      const int white_win        = book.whiteWinCount(next_state_index);
+      std::cout << "  " << osl::csa::show(moves[i].move)
+		<< "(" << moves[i].weight << "," << black_win << "," << white_win << ")";
     }
     std::cout << "\n";
   }
@@ -165,40 +156,40 @@ void show_history(const osl::MoveVector& history)
 {
   std::cout << "[" << history.size() << "]";
   for (size_t i=0; i<history.size(); ++i)
-    std::cout << " " << osl::record::csa::show(history[i]);
+    std::cout << " " << osl::csa::show(history[i]);
   std::cout << std::endl;
 }
 
-osl::MoveVector make_history(osl::record::opening::WeightedBook& book, const osl::vector<int>& parents, int node)
+osl::MoveVector make_history(osl::book::WeightedBook& book, const std::vector<int>& parents, int node)
 {
-  osl::vector<int> history;
+  std::vector<int> history;
   history.push_back(node);
   while (parents[node] >= 0) {
     node = parents[node];
     history.push_back(node);
   }
   std::reverse(history.begin(), history.end());
-  assert(book.getStartState() == history[0]);
+  assert(book.startState() == history[0]);
 
   osl::MoveVector result;  
   for (size_t i=0; i<history.size()-1; ++i) {
-    const WMoveContainer& moves = book.getMoves(history[i]);  
+    const WMoveContainer& moves = book.moves(history[i]);  
     for (WMoveContainer::const_iterator p=moves.begin(); p!=moves.end(); ++p) {
-      if (p->getStateIndex() != history[i+1])
+      if (p->stateIndex() != history[i+1])
 	continue;
-      result.push_back(p->getMove());
+      result.push_back(p->move);
       break;
     }
   }
   return result;
 }
 
-void dump(osl::record::opening::WeightedBook& book_a, const osl::vector<int>& parents_a, int node_a, 
-	  osl::record::opening::WeightedBook& book_b, const osl::vector<int>& parents_b, int node_b)
+void dump(osl::book::WeightedBook& book_a, const std::vector<int>& parents_a, int node_a, 
+	  osl::book::WeightedBook& book_b, const std::vector<int>& parents_b, int node_b)
 {
-  const osl::state::NumEffectState state(book_a.getBoard(node_a));
+  const osl::NumEffectState state(book_a.board(node_a));
   osl::record::KanjiPrint printer(std::cout, 
-				  boost::shared_ptr<osl::record::Characters>(
+				  std::shared_ptr<osl::record::Characters>(
 				    new osl::record::KIFCharacters())
     );
   printer.print(state);
@@ -211,11 +202,11 @@ void dump(osl::record::opening::WeightedBook& book_a, const osl::vector<int>& pa
   show_moves("b", book_b, node_b);
 }
 
-void dump(const char *name, osl::record::opening::WeightedBook& book, const osl::vector<int>& parents, int node)
+void dump(const char *name, osl::book::WeightedBook& book, const std::vector<int>& parents, int node)
 {
-  const osl::state::NumEffectState state(book.getBoard(node));
+  const osl::NumEffectState state(book.board(node));
   osl::record::KanjiPrint printer(std::cout, 
-				  boost::shared_ptr<osl::record::Characters>(
+				  std::shared_ptr<osl::record::Characters>(
 				    new osl::record::KIFCharacters())
     );
   printer.print(state);
@@ -223,31 +214,31 @@ void dump(const char *name, osl::record::opening::WeightedBook& book, const osl:
   show_moves(name, book, node);
 }
 
-bool is_same_node(osl::record::opening::WeightedBook& book_a, int node_a, 
-		  osl::record::opening::WeightedBook& book_b, int node_b)
+bool is_same_node(osl::book::WeightedBook& book_a, int node_a, 
+		  osl::book::WeightedBook& book_b, int node_b)
 {
-  WMoveContainer moves_a = book_a.getMoves(node_a);
-  WMoveContainer moves_b = book_b.getMoves(node_b);
+  WMoveContainer moves_a = book_a.moves(node_a);
+  WMoveContainer moves_b = book_b.moves(node_b);
   
-  std::sort(moves_a.begin(), moves_a.end(), osl::record::opening::WMoveWeightMoveSort());
-  std::sort(moves_b.begin(), moves_b.end(), osl::record::opening::WMoveWeightMoveSort());
+  std::sort(moves_a.begin(), moves_a.end(), osl::book::WMoveWeightMoveSort());
+  std::sort(moves_b.begin(), moves_b.end(), osl::book::WMoveWeightMoveSort());
 
   size_t i=0;
   for (; i<std::min(moves_a.size(), moves_b.size()); ++i) {
-    if (moves_a[i].getWeight() == 0)
-      return moves_b[i].getWeight() == 0;
-    if (moves_b[i].getWeight() == 0)
+    if (moves_a[i].weight == 0)
+      return moves_b[i].weight == 0;
+    if (moves_b[i].weight == 0)
       return false;
-    if (moves_a[i].getMove() != moves_b[i].getMove())
+    if (moves_a[i].move != moves_b[i].move)
       return false;
   }
   if (i == moves_a.size())
-    return i == moves_b.size() || moves_b[i].getWeight() == 0;
-  return moves_a[i].getWeight() == 0;
+    return i == moves_b.size() || moves_b[i].weight == 0;
+  return moves_a[i].weight == 0;
 }
 
-void compare(osl::record::opening::WeightedBook& book_a, const table_t& table_a, const osl::vector<int>& parents_a,
-	     osl::record::opening::WeightedBook& book_b, const table_t& table_b, const osl::vector<int>& parents_b)
+void compare(osl::book::WeightedBook& book_a, const table_t& table_a, const std::vector<int>& parents_a,
+	     osl::book::WeightedBook& book_b, const table_t& table_b, const std::vector<int>& parents_b)
 {
   long only_a = 0, only_b = 0, same = 0, diff = 0;
   for (table_t::const_iterator p=table_a.begin(); p!=table_a.end(); ++p) {
@@ -341,8 +332,8 @@ int main(int argc, char **argv)
     return 1;
   }
 
-  osl::record::opening::WeightedBook book_a(filenames[0].c_str()), book_b(filenames[1].c_str());
-  osl::CArray<osl::vector<int>,2> parents;
+  osl::book::WeightedBook book_a(filenames[0].c_str()), book_b(filenames[1].c_str());
+  osl::CArray<std::vector<int>,2> parents;
   osl::CArray<table_t,2> tables;
   std::cout << boost::format("Book: %s\n") % filenames[0];
   store(book_a, tables[0], parents[0]);
