@@ -1,20 +1,19 @@
-#include "osl/record/opening/openingBook.h"
-#include "osl/record/csa.h"
+#include "osl/book/openingBook.h"
+#include "osl/csa.h"
 #include "osl/search/quiescenceSearch2.h"
 #include "osl/search/quiescenceSearch2.tcc"
 #include "osl/eval/pieceEval.h"
-#include "osl/stl/vector.h"
 #include <iostream>
 #include <cstring>
 
-using namespace osl::record::opening;
+using namespace osl::book;
 
 
-static int qsearch(osl::state::SimpleState &s, osl::Move lastMove)
+static int qsearch(osl::SimpleState &s, osl::Move lastMove)
 {
   typedef osl::search::QuiescenceSearch2<osl::eval::PieceEval> qsearch_t;
 
-  osl::state::NumEffectState state(s);
+  osl::NumEffectState state(s);
   osl::search::SimpleHashTable table(100000, -16, false);
   osl::search::SearchState2Core::checkmate_t checkmate_searcher;
   osl::search::SearchState2Core core(state, checkmate_searcher);
@@ -32,12 +31,12 @@ int main(int argc, char **argv)
   }
 
   WeightedBook book(argv[1]);
-  bool states[book.getTotalState()];
+  bool states[book.totalState()];
 
-  memset(states, 0, sizeof(bool) * book.getTotalState());
-  osl::stl::vector<int> stateToVisit;
+  memset(states, 0, sizeof(bool) * book.totalState());
+  std::vector<int> stateToVisit;
 
-  stateToVisit.push_back(book.getStartState());
+  stateToVisit.push_back(book.startState());
   const int threshold = osl::eval::Ptype_Eval_Table.value(osl::SILVER);
 
   while (!stateToVisit.empty())
@@ -46,16 +45,16 @@ int main(int argc, char **argv)
     stateToVisit.pop_back();
     states[stateIndex] = true;
 
-    osl::state::SimpleState state = book.getBoard(stateIndex);
+    osl::SimpleState state = book.board(stateIndex);
     int value = qsearch(state,
 			osl::Move::PASS(alt(state.turn())));
 
-    const osl::stl::vector<WMove> moves = book.getMoves(stateIndex);
+    const auto moves = book.moves(stateIndex);
     for (size_t i = 0; i < moves.size(); i++)
     {
-      const int nextIndex = moves[i].getStateIndex();
-      osl::state::SimpleState newState = book.getBoard(nextIndex);
-      osl::Move move = moves[i].getMove();
+      const int nextIndex = moves[i].stateIndex();
+      osl::SimpleState newState = book.board(nextIndex);
+      osl::Move move = moves[i].move;
       int newValue = qsearch(newState, move);
 
       int diff = newValue - value;
@@ -64,12 +63,12 @@ int main(int argc, char **argv)
       if ((state.turn() == osl::BLACK && diff < -threshold)
 	  || (state.turn() == osl::WHITE && diff > threshold))
 	std::cout << "----" << std::endl
-		  << state << osl::record::csa::show(move) << std::endl;
+		  << state << osl::csa::show(move) << std::endl;
       // the gain too big
       if ((state.turn() == osl::BLACK && diff > threshold)
 	  || (state.turn() == osl::WHITE && diff < -threshold))
 	std::cout << "++++" << std::endl
-		  << state << osl::record::csa::show(move) << std::endl;
+		  << state << osl::csa::show(move) << std::endl;
 
       if (! states[nextIndex])
       {
