@@ -1,7 +1,7 @@
 #ifndef _OPENING_BOOK_CONVERTER_H
 #define _OPENING_BOOK_CONVERTER_H
 
-#include <osl/record/opening/openingBook.h>
+#include "osl/book/openingBook.h"
 
 class OBState
 {
@@ -22,8 +22,8 @@ class OBState
 
 class OpeningBookConverter
 {
-  osl::vector<OBState> states;
-  osl::vector<osl::record::opening::OBMove> moves;
+  std::vector<OBState> states;
+  std::vector<osl::book::OBMove> moves;
  public:
   OpeningBookConverter(const char* filename);
   ~OpeningBookConverter() {};
