@@ -1,34 +1,25 @@
-#include "osl/move.h"
+#include "osl/book/openingBook.h"
 #include "osl/eval/pieceEval.h"
-#include "osl/hash/hashKey.h"
+#include "osl/hashKey.h"
 #include "osl/misc/math.h"
-#include "osl/record/csa.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/kanjiPrint.h"
-#include "osl/record/record.h"
-#include "osl/record/opening/openingBook.h"
 #include "osl/search/fixedEval.h"
 #include "osl/search/quiescenceSearch2.h"
 #include "osl/search/quiescenceSearch2.tcc"
 #include "osl/search/simpleHashTable.h"
-#include "osl/state/numEffectState.h"
-#include "osl/stl/vector.h"
 #include <boost/format.hpp>
-#include <boost/lambda/lambda.hpp>
-#include <boost/lambda/bind.hpp>
 #include <boost/program_options.hpp>
 #include <boost/progress.hpp>
-#include <boost/shared_ptr.hpp>
 #include <deque>
 #include <iostream>
 #include <vector>
 
 
-using namespace boost::lambda;
 namespace bp = boost::program_options;
 bp::variables_map vm;
 
-typedef std::vector<osl::record::opening::WMove> WMoveContainer;
+typedef std::vector<osl::book::WMove> WMoveContainer;
 
 osl::Player the_player = osl::BLACK;
 bool is_dump = false;
@@ -38,7 +29,7 @@ int max_depth, non_determinate_depth;
 double ratio;		   // use moves[n+1] when the weight[n+1] >= ratio*weight[n]
 bool is_quick = false;
 
-boost::shared_ptr<osl::NumEffectState> state_to_compare;
+std::shared_ptr<osl::NumEffectState> state_to_compare;
 size_t state_count = 0;
 
 /**
@@ -48,13 +39,13 @@ size_t state_count = 0;
  * @param lastMove
  * @return evaluation value
  */
-int qsearch(const osl::state::SimpleState &s, 
+int qsearch(const osl::SimpleState &s, 
             const osl::Move& lastMove)
 {
   if (is_quick) return 0;
 
   typedef osl::search::QuiescenceSearch2<osl::eval::PieceEval> qsearch_t;
-  osl::state::NumEffectState state(s);
+  osl::NumEffectState state(s);
   osl::search::SimpleHashTable table(100000, -1, false);
   osl::search::SearchState2Core::checkmate_t checkmate_searcher;
   osl::search::SearchState2Core core(state, checkmate_searcher);
@@ -83,31 +74,31 @@ void printUsage(std::ostream& out,
       << std::endl;
 }
 
-void showInfoOfState(osl::record::opening::WeightedBook& book, const int state_index)
+void showInfoOfState(osl::book::WeightedBook& book, const int state_index)
 {
   osl::record::KanjiPrint printer(std::cerr, 
-                                  boost::shared_ptr<osl::record::Characters>(
+                                  std::shared_ptr<osl::record::Characters>(
                                             new osl::record::KIFCharacters())
                                   );
 
   std::cout << boost::format("state_index: %g\n") % state_index
-            << boost::format("black win:   %g\n") % book.getBlackWinCount(state_index)
-            << boost::format("white win:   %g\n") % book.getWhiteWinCount(state_index);
+            << boost::format("black win:   %g\n") % book.blackWinCount(state_index)
+            << boost::format("white win:   %g\n") % book.whiteWinCount(state_index);
 
   std::cout << "\nTarget state:\n";
-  printer.print(book.getBoard(state_index));
+  printer.print(book.board(state_index));
   std::cout << "\n";
 
-  WMoveContainer moves = book.getMoves(state_index);
+  WMoveContainer moves = book.moves(state_index);
   std::cout << boost::format("found %g moves\n") % moves.size();
-  std::sort(moves.begin(), moves.end(), osl::record::opening::WMoveSort());
+  std::sort(moves.begin(), moves.end(), osl::book::WMoveSort());
   for (WMoveContainer::const_iterator each = moves.begin();
        each != moves.end(); ++each)
   {
-    std::cout << boost::format("[%g] %g") % each->getWeight() % each->getMove();
-    const int next_index = each->getStateIndex();
+    std::cout << boost::format("[%g] %g") % each->weight % each->move;
+    const int next_index = each->stateIndex();
     std::cout << "\n";
-    printer.print(book.getBoard(next_index));
+    printer.print(book.board(next_index));
   }
 }
 
@@ -115,29 +106,29 @@ void showInfoOfState(osl::record::opening::WeightedBook& book, const int state_i
 void doMain(const std::string& file_name)
 {
   osl::record::KanjiPrint printer(std::cerr, 
-                                  boost::shared_ptr<osl::record::Characters>(
+                                  std::shared_ptr<osl::record::Characters>(
                                             new osl::record::KIFCharacters())
                                   );
   if (vm.count("verbose"))
     std::cout << boost::format("Opening... %s\n ") % file_name;
-  osl::record::opening::WeightedBook book(file_name.c_str());
+  osl::book::WeightedBook book(file_name.c_str());
 
   if (vm.count("verbose"))
-    std::cout << boost::format("Total states: %d\n") % book.getTotalState();
-  bool states[book.getTotalState()]; // mark states that have been visited.
-  memset(states, 0, sizeof(bool) * book.getTotalState());
-  boost::progress_display progress(book.getTotalState());
+    std::cout << boost::format("Total states: %d\n") % book.totalState();
+  bool states[book.totalState()]; // mark states that have been visited.
+  memset(states, 0, sizeof(bool) * book.totalState());
+  boost::progress_display progress(book.totalState());
 
   int state_index_to_compare = -1;
   if (state_to_compare)
-    state_index_to_compare = book.getStateIndex(*state_to_compare);
+    state_index_to_compare = book.stateIndex(*state_to_compare);
 
   typedef std::pair<int, int> state_depth_t;
-  osl::stl::vector<state_depth_t> stateToVisit;
+  std::vector<state_depth_t> stateToVisit;
 
   if (vm.count("verbose"))
-    std::cout << boost::format("Start index: %d\n)") % book.getStartState();
-  stateToVisit.push_back(state_depth_t(book.getStartState(), 1)); // root is 1
+    std::cout << boost::format("Start index: %d\n)") % book.startState();
+  stateToVisit.push_back(state_depth_t(book.startState(), 1)); // root is 1
   // depth-1手目からdepth手目のstate。depth手目はまだ指されていない（これか
   // らdepth手目）
 
@@ -162,7 +153,7 @@ void doMain(const std::string& file_name)
         state_index_to_compare == stateIndex)
       ++state_count;
 
-    WMoveContainer moves = book.getMoves(stateIndex);
+    WMoveContainer moves = book.moves(stateIndex);
     if (vm.count("verbose"))
       std::cout << boost::format("  #moves... %d\n") % moves.size();
     
@@ -172,17 +163,17 @@ void doMain(const std::string& file_name)
           ((the_player == osl::BLACK && depth % 2 == 1) ||
            (the_player == osl::WHITE && depth % 2 == 0)) )
     {
-      std::sort(moves.begin(), moves.end(), osl::record::opening::WMoveSort());
+      std::sort(moves.begin(), moves.end(), osl::book::WMoveSort());
       int min = 1;
       if (is_determinate) 
       {
-	min = moves.at(0).getWeight();
+	min = moves.at(0).weight;
 	if (depth <= non_determinate_depth) 
 	{
 	  for (int i=1; i<=std::min(is_determinate, (int)moves.size()-1); ++i) 
 	  {
-	    const int weight = moves.at(i).getWeight();
-	    if ((double)weight < (double)moves.at(i-1).getWeight()*ratio)
+	    const int weight = moves.at(i).weight;
+	    if ((double)weight < (double)moves.at(i-1).weight*ratio)
 	      break;
 	    min = weight;
 	  }
@@ -194,7 +185,7 @@ void doMain(const std::string& file_name)
       WMoveContainer::iterator each = moves.begin();
       for (; each != moves.end(); ++each)
       {
-        if (each->getWeight() < min)
+        if (each->weight < min)
           break;
       }
       moves.erase(each, moves.end());
@@ -202,7 +193,7 @@ void doMain(const std::string& file_name)
 
     if (moves.empty() || depth > max_depth) // found leaves
     {
-      const osl::state::NumEffectState state(book.getBoard(stateIndex));
+      const osl::NumEffectState state(book.board(stateIndex));
       const int value = qsearch(state, osl::Move::PASS(alt(state.turn())));
 
       if ( (the_player == osl::BLACK && value < -1 * error_threshold) ||
@@ -225,19 +216,19 @@ void doMain(const std::string& file_name)
     }
 
     // 結果の再現性を高めるため、visitの順番を決める
-    std::sort(moves.begin(), moves.end(), osl::record::opening::WMoveMoveSort());
+    std::sort(moves.begin(), moves.end(), osl::book::WMoveMoveSort());
 
     // recursively search the tree
-    for (std::vector<osl::record::opening::WMove>::const_iterator each = moves.begin();
+    for (std::vector<osl::book::WMove>::const_iterator each = moves.begin();
          each != moves.end(); ++each)
     {
       // consistancy check
-      const osl::SimpleState state(book.getBoard(stateIndex));
+      const osl::SimpleState state(book.board(stateIndex));
       const osl::hash::HashKey hash(state);
-      const int nextIndex = each->getStateIndex();
-      const osl::SimpleState next_state(book.getBoard(nextIndex));
+      const int nextIndex = each->stateIndex();
+      const osl::SimpleState next_state(book.board(nextIndex));
       const osl::hash::HashKey next_hash(next_state);
-      const osl::hash::HashKey moved_hash = hash.newMakeMove(each->getMove());
+      const osl::hash::HashKey moved_hash = hash.newMakeMove(each->move);
       if (moved_hash != next_hash)
         throw std::string("Illegal move found.");
 
@@ -278,8 +269,8 @@ void doMain(const std::string& file_name)
     std::cout << "\nthe state hits: " << state_count << std::endl;
     printer.print(*state_to_compare);
 
-    const int stateIndex  = book.getStateIndex(*state_to_compare);
-    const std::vector<int> parents = book.getParents(stateIndex);
+    const int stateIndex  = book.stateIndex(*state_to_compare);
+    const std::vector<int> parents = book.parents(stateIndex);
     if (parents.empty())
     {
       std::cout << "\nNo parent\n";
@@ -369,11 +360,11 @@ int main(int argc, char **argv)
   if (!csa_file_name.empty())
   {
     is_quick = true;
-    const osl::record::csa::CsaFile csa(csa_file_name);
-    const osl::record::Record record = csa.getRecord();
-    const osl::stl::vector<osl::Move> moves = record.getMoves();
-    const osl::SimpleState initialState = record.getInitialState();
-    state_to_compare.reset(new osl::NumEffectState(initialState));
+    const osl::CsaFile csa(csa_file_name);
+    const osl::Record record = csa.load();
+    const auto moves = record.moves();
+    const auto initial_state = record.initialState();
+    state_to_compare.reset(new osl::NumEffectState(initial_state));
 
     if (csa_move_index < 1) csa_move_index = 1;
     if (csa_move_index > moves.size()) csa_move_index = moves.size();
