@@ -1,7 +1,7 @@
 /**
  * 詰将棋の指手生成の速さを見る
  */
-#include "osl/record/csaString.h"
+#include "osl/csa.h"
 
 #define NO_SAFE_MOVE_ACTION_IN_LIBOSL
 #define SIMPLE_STATE_ONLY
