@@ -1,7 +1,7 @@
 /* pin_perf.cc
  */
 #include "osl/effect_util/pin.h"
-#include "osl/record/csaString.h"
+#include "osl/csa.h"
 #include "osl/record/csaRecord.h"
 #include "osl/misc/perfmon.h"
 
@@ -68,9 +68,9 @@ void run(const char *filename)
   unsigned long long total_cycles_step=0;
   unsigned long long total_cycles_step1=0;
   unsigned long long positions = 0;
-  Record rec=CsaFile(filename).getRecord();
-  NumEffectState state(rec.getInitialState());
-  const vector<osl::Move> moves=rec.getMoves();
+  CsaFileMinimal csa(filename);
+  NumEffectState state(csa.initialState());
+  const auto moves=csa.moves();
 
   size_t i=0;
   while (true)
