@@ -2,7 +2,7 @@
  */
 #include "osl/progress/effect5x3.h"
 #include "osl/progress/effect5x3d.h"
-#include "osl/record/csaString.h"
+#include "osl/csa.h"
 #include "osl/record/csaRecord.h"
 #include "osl/misc/perfmon.h"
 
@@ -68,9 +68,9 @@ unsigned long long total_cycles_naive=0;
 unsigned long long positions = 0;
 void run(const char *filename)
 {
-  Record rec=CsaFile(filename).getRecord();
-  NumEffectState state(rec.getInitialState());
-  const vector<osl::Move> moves=rec.getMoves();
+  CsaFile csa(filename);
+  NumEffectState state(csa.initialState());
+  const auto moves=csa.moves();
 
   size_t i=0;
   progress::Effect5x3 progress(state);
