@@ -4,7 +4,6 @@
 #include "osl/effect_util/sendOffSquare.h"
 #include "osl/effect_util/effectUtil.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaIOError.h"
 #include "osl/stat/average.h"
 #include "osl/misc/perfmon.h"
 
@@ -74,13 +73,13 @@ int main(int argc, char **argv)
   }
 
   std::cout << "\n"
-	    << "average moves/position " << moves.getAverage() << "\n"
-	    << "average order " << order.getAverage() << "\n"
-	    << "average selected score " << selected_score.getAverage() << "\n"
+	    << "average moves/position " << moves.average() << "\n"
+	    << "average order " << order.average() << "\n"
+	    << "average selected score " << selected_score.average() << "\n"
 	    << "min selected score " << min_selected << "\n"
-	    << "average top score " << top_score.getAverage() << "\n";
-  std::cout << "average cycles/position " << cycles.getAverage() << "\n"
-	    << "average cycles/position/move " << cycles_per_move.getAverage()
+	    << "average top score " << top_score.average() << "\n";
+  std::cout << "average cycles/position " << cycles.average() << "\n"
+	    << "average cycles/position/move " << cycles_per_move.average()
 	    << "\n";
 }
 
@@ -121,9 +120,9 @@ void test_position(const FeatureSet& f, Move next_move, Move last_move, const Ra
 
 void test_file(const FeatureSet& f, const char *filename)
 {
-  Record rec;
+  RecordMinimal record;
   try {
-    rec = CsaFile(filename).getRecord();
+    record = CsaFileMinimal(filename).load();
   }
   catch (CsaIOError& e) {
     std::cerr << "skip " << filename <<"\n";
@@ -134,8 +133,8 @@ void test_file(const FeatureSet& f, const char *filename)
     throw;
   }
   
-  NumEffectState state(rec.getInitialState());
-  const osl::stl::vector<osl::Move> moves=rec.getMoves();
+  NumEffectState state(record.initialState());
+  const auto& moves=record.moves;
 
   RatingEnv env;
   env.make(state);
