@@ -2,9 +2,6 @@
 #include "osl/eval/pieceEval.h"
 #include "osl/effect_util/pin.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaIOError.h"
-#include "osl/move_generator/legalMoves.h"
-#include "osl/container/moveVector.h"
 #include "osl/stat/average.h"
 #include "osl/misc/perfmon.h"
 
@@ -71,8 +68,8 @@ int main(int argc, char **argv)
     test_file(argv[i]);
   }
 
-  std::cout << "average cycles/position " << cycles.getAverage() << "\n"
-	    << "average cycles/position/move " << cycles_per_move.getAverage()
+  std::cout << "average cycles/position " << cycles.average() << "\n"
+	    << "average cycles/position/move " << cycles_per_move.average()
 	    << "\n";
 }
 
@@ -82,7 +79,7 @@ size_t num_positions = 0;
 void test_position(const NumEffectState& state)
 {
   MoveVector moves;
-  LegalMoves::generate(state, moves);
+  state.generateLegal(moves);
   const PieceMask my_pin = effect_util::Pin::make(state, state.turn());
   const PieceMask op_pin = effect_util::Pin::make(state, alt(state.turn()));
   
@@ -101,9 +98,9 @@ void test_position(const NumEffectState& state)
 
 void test_file(const char *filename)
 {
-  Record rec;
+  RecordMinimal record;
   try {
-    rec = CsaFile(filename).getRecord();
+    record = CsaFileMinimal(filename).load();
   }
   catch (CsaIOError& e) {
     std::cerr << "skip " << filename <<"\n";
@@ -114,8 +111,8 @@ void test_file(const char *filename)
     throw;
   }
   
-  NumEffectState state(rec.getInitialState());
-  const osl::stl::vector<osl::Move> moves=rec.getMoves();
+  NumEffectState state(record.initialState());
+  const auto moves=record.moves;
 
   for (size_t i=0; i<moves.size(); ++i) {
     const Move move = moves[i];
