@@ -4,8 +4,8 @@
  * maxLevel=3,moveCount=444378267,dropCount=357602901,sec=11.630000,count/s=38209653.224420
  * という結果だった．
  */
-#include "osl/record/csaString.h"
-#include "osl/state/numEffectState.h"
+#include "osl/csa.h"
+#include "osl/numEffectState.h"
 
 #ifdef MORE_STATE
 #  include "osl/boardBitEffect.h"
@@ -17,10 +17,9 @@
 #  include "osl/pieceEval.h"
 #endif
 
-#include "osl/player.h"
 #include "osl/move_generator/allMoves.h"
 #include "osl/move_generator/allMoves.tcc"
-#include "osl/move_action/store.h"
+#include "osl/move_generator/move_action.h"
 #include "osl/misc/perfmon.h"
 #include <iostream>
 #include <time.h>
@@ -71,7 +70,7 @@ template<Player P,typename State,bool isMoveEval>
 void nextMoves(State& state,int level){
   if(level>maxLevel) return;
   MoveVector moves;
-  DoUndoHelper<State,PlayerTraits<P>::opponent,isMoveEval> helper(state, level+1);
+  DoUndoHelper<State,alt(P),isMoveEval> helper(state, level+1);
   GenerateAllMoves::generate(P,state,moves);
 
   size_t size=moves.size();
@@ -195,7 +194,7 @@ int main(int argc,char **argv){
 			      "P9-RY *  *  *  *  *  *  * +KY\n"
 			      "P+00KA00KY00FU00FU00FU00FU\n"
 			      "P-00KI00KI00KE00KE00KY\n"
-			      "+\n").getInitialState();
+			      "+\n").initialState();
   maxLevel=level;
   moveCount=0;
   dropCount=0;
