@@ -2,9 +2,8 @@
  */
 
 #include "osl/progress/effect5x3.h"
-#include "osl/progress/ml/newProgress.h"
+#include "osl/progress.h"
 #include "osl/record/csaRecord.h"
-#include "osl/state/numEffectState.h"
 #include <stdexcept>
 #include <iostream>
 #include <iomanip>
@@ -71,9 +70,9 @@ void show(const NumEffectState& state)
 void show(const char *filename)
 {
   std::cout << filename << "\n";
-  CsaFile file(filename);
-  const vector<osl::Move> moves = file.getRecord().getMoves();
-  NumEffectState state(file.getInitialState());
+  CsaFileMinimal file(filename);
+  const auto moves = file.load().moves;
+  NumEffectState state(file.load().initial_state);
   for (unsigned int i=0; i<moves.size(); i++)
   {
     if (show_all_states)
