@@ -4,9 +4,8 @@
 #include "osl/search/simpleHashTable.h"
 #include "osl/search/searchState2.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/record/csaString.h"
 #include "osl/record/csaRecord.h"
-#include "osl/eval/ml/openMidEndingEval.h"
+#include "osl/eval/openMidEndingEval.h"
 #include "osl/misc/perfmon.h"
 
 #include <iostream>
@@ -87,9 +86,9 @@ void qsearch(const char *filename)
     std::cerr << filename;
   unsigned long long total_cycles=0;
   unsigned long long positions = 0;
-  Record rec=CsaFile(filename).getRecord();
-  NumEffectState state(rec.getInitialState());
-  const vector<osl::Move> moves=rec.getMoves();
+  Record record=CsaFile(filename).load();
+  NumEffectState state(record.initialState());
+  const auto moves=record.moves();
 
   typedef QuiescenceSearch2<eval::ml::OpenMidEndingEval> qsearch_t;
 
@@ -122,10 +121,10 @@ void qsearch(const char *filename)
 	const SimpleHashRecord *record = table.find(HashKey(state));
 	std::cout << "result ";
 	if (record)
-	  std::cout << record::csa::show(record->qrecord.bestMove()) << " ";
+	  std::cout << csa::show(record->qrecord.bestMove()) << " ";
 	std::cout << val << "\n";
 	if (i < moves.size())
-	  std::cout << "recorded " << record::csa::show(moves[i]) << "\n";
+	  std::cout << "recorded " << csa::show(moves[i]) << "\n";
       }
     }
     if (i >= moves.size() || problem_solving)
