@@ -4,9 +4,8 @@
 #include "osl/search/quiescenceSearch2.tcc"
 #include "osl/search/quiescenceLog.h"
 #include "osl/search/simpleHashTable.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/record/csaString.h"
 #include "osl/record/csaRecord.h"
 #include "osl/eval/pieceEval.h"
 #include "osl/eval/progressEval.h"
@@ -95,9 +94,9 @@ void qsearch(const char *filename)
 {
   unsigned long long total_cycles=0;
   unsigned long long positions = 0;
-  Record rec=CsaFile(filename).getRecord();
-  NumEffectState state(rec.getInitialState());
-  const vector<osl::Move> moves=rec.getMoves();
+  Record record=CsaFile(filename).load();
+  NumEffectState state(record.initialState());
+  const auto moves=record.moves();
 
   typedef QuiescenceSearch2<Eval> qsearch_t;
 
