@@ -22,13 +22,12 @@
 #include "osl/search/quiescenceSearch2.tcc"
 #include "osl/search/simpleHashTable.h"
 #include "osl/checkmate/dualDfpn.h"
-#include "osl/state/numEffectState.h"
-#include "osl/record/csaString.h"
+#include "osl/numEffectState.h"
 #include "osl/record/csaRecord.h"
 #include "osl/eval/progressEval.h"
 #include "osl/stat/average.h"
+#include <forward_list>
 
-#include "osl/stl/slist.h"
 #include <iostream>
 #include <cstdio>
 #include <fstream>
@@ -145,8 +144,8 @@ public:
   {
     const std::string n = name();    
     fprintf(stderr, "%s\t%8.3f\t%8.3f\t%10.3f\t%8.3f\n",
-	    n.c_str(), width.getAverage(), nodes.getAverage(),
-	    diff.getAverage(), accuracy.getAverage());
+	    n.c_str(), width.average(), nodes.average(),
+	    diff.average(), accuracy.average());
   };
 };
 
@@ -387,7 +386,7 @@ class Analyzer
   SimpleHashTable table;
   qsearch_t *qs;
   FullWidth full_searcher;
-  typedef slist<Searcher*> list_t;
+  typedef std::forward_list<Searcher*> list_t;
   list_t searchers;
 public:
   Analyzer() : records(0), state(SimpleState(HIRATE)), ev(state),
@@ -451,7 +450,7 @@ public:
     const int pawn_value
       = qsearch_t::eval_t::captureValue(newPtypeO(alt(turn),PAWN));
     if (verbose)
-      std::cerr << i << " " << record::csa::show(last_move) << "\n";
+      std::cerr << i << " " << csa::show(last_move) << "\n";
 
     table.clear();
     const int real_value_dummy = 0;
@@ -466,10 +465,10 @@ public:
   }
   void search(const char *filename)
   {
-    Record rec=CsaFile(filename).getRecord();
-    state = NumEffectState(rec.getInitialState());
+    Record record=CsaFile(filename).load();
+    state = NumEffectState(record.initialState());
     ev = eval_t(state);
-    const vector<osl::Move> moves=rec.getMoves();
+    const auto moves=record.moves();
     size_t i=0;
     while (true)
     {
