@@ -1,13 +1,10 @@
 /* random_play.cc
  */
-#include "osl/state/numEffectState.h"
-#include "osl/effect_util/effectUtil.h"
-#include "osl/container/moveVector.h"
-#include "osl/record/csa.h"
-#include "osl/move_generator/legalMoves.h"
-#include <boost/random/mersenne_twister.hpp>
-// #include <boost/random/uniform_int.hpp>
+#include "osl/numEffectState.h"
+#include "osl/csa.h"
 #include <string>
+#include <iostream>
+#include <random>
 #include <sys/time.h>
 using namespace osl;
 
@@ -29,7 +26,7 @@ void showState(const NumEffectState& state)
  */
 Move selectMove(const NumEffectState& state, const MoveVector& moves)
 {
-  static boost::mt11213b generator(random());
+  static std::mt19937 generator(random());
   return moves[generator() % moves.size()];
 #if 0
   boost::uniform_int<boost::mt11213b> random(generator, 0, moves.size());
@@ -49,13 +46,13 @@ int main()
 {
   srandom(time(0));
 
-  NumEffectState state((SimpleState(HIRATE)));
+  NumEffectState state;
   std::string line;
   while (true)
   {
     // 自分の手を指す
     MoveVector moves;
-    LegalMoves::generate(state, moves);
+    state.generateLegal(moves);
     if (moves.empty())
     {
       std::cerr << "make masita\n";
@@ -66,8 +63,7 @@ int main()
     state.makeMove(my_move);
 
     showState(state);
-    csaShow(std::cout, my_move);
-    std::cout << "\n";
+    std::cout << csa::show(my_move) << "\n";
 
     if (isMated(state))
     {
@@ -79,15 +75,14 @@ int main()
     if (! std::getline(std::cin, line))
       break;
 
-    const Move op_move=record::csa::strToMove(line, state);
+    const Move op_move=csa::strToMove(line, state);
     if (! state.isValidMove(op_move))
       break;
     
     state.makeMove(op_move);
 
     showState(state);
-    csaShow(std::cout, op_move);
-    std::cout << "\n";
+    std::cout << csa::show(op_move) << "\n";
   } 
 }
 
