@@ -4,12 +4,10 @@
 #include "osl/eval/progressEval.h"
 #include "osl/effect_util/effectUtil.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csaIOError.h"
 #include "osl/record/kisen.h"
 #include "osl/misc/perfmon.h"
 #include "osl/stat/histogram.h"
 #include "osl/stat/variance.h"
-#include "osl/stl/vector.h"
 
 #include <boost/format.hpp>
 #include <string>
@@ -380,7 +378,7 @@ namespace osl
       for (int i=0; i<sc_length_2d; ++i) {
 	for (int j=0; j<sc_length_2d; ++j) {
 	  // os << std::setw(5) << std::setprecision(3) << variance[i*sc_length_2d+j].getAverage();
-	  os << std::setw(5) << static_cast<int>(variance[i*sc_length_2d+j].getAverage());
+	  os << std::setw(5) << static_cast<int>(variance[i*sc_length_2d+j].average());
 	}
 	os << "\n";
       }
@@ -420,7 +418,7 @@ CArray<stat::Variance, 8> top_rating_progress;
 void test_file(const FeatureSet&, const char *filename);
 void test_record(const FeatureSet& f, 
 		 const SimpleState& initial,
-		 const osl::stl::vector<osl::Move>& moves);
+		 const std::vector<osl::Move>& moves);
 
 int main(int argc, char **argv)
 {
@@ -459,14 +457,14 @@ int main(int argc, char **argv)
     KisenIpxFile ipx(kisen_file.ipxFileName());
     size_t skip = 0;
     for (size_t i=0; i<num_kisen; i++) {
-      if (ipx.getRating(i, BLACK) < min_rating 
-	  || ipx.getRating(i, WHITE) < min_rating) {
+      if (ipx.rating(i, BLACK) < min_rating 
+	  || ipx.rating(i, WHITE) < min_rating) {
 	++skip;
 	continue;
       }
       if (i % 128 == 0)
 	std::cerr << '.';
-      test_record(f, kisen_file.getInitialState(), kisen_file.getMoves(i+kisen_start));
+      test_record(f, kisen_file.initialState(), kisen_file.moves(i+kisen_start));
     }
   }
   
@@ -478,11 +476,11 @@ int main(int argc, char **argv)
   }
 
   std::cout << "\n"
-	    << "average moves/position " << moves.getAverage() << "\n"
-	    << "average order " << order.getAverage() << "\n"
-	    << "average selected score " << selected_score.getAverage() << "\n"
+	    << "average moves/position " << moves.average() << "\n"
+	    << "average order " << order.average() << "\n"
+	    << "average selected score " << selected_score.average() << "\n"
 	    << "min selected score " << min_selected.value() << "\n"
-	    << "average top score " << top_score.getAverage() << "\n"
+	    << "average top score " << top_score.average() << "\n"
 	    << "min top score " << min_top.value() << "\n"
 	    << "max top score (notakeback) " << max_notakeback.value() << "\n"
 	    << "max top score (nocapture) " << max_nocapture.value() << "\n";
@@ -525,7 +523,7 @@ int main(int argc, char **argv)
   }
   std::cout << "top rating for each progress8\n";
   for (size_t i=0; i<top_rating_progress.size(); ++i)
-    std::cout << "progress8 " << i << "\tave. " << std::setprecision(3) << top_rating_progress[i].getAverage()
+    std::cout << "progress8 " << i << "\tave. " << std::setprecision(3) << top_rating_progress[i].average()
 	      << "\tsigma " << sqrt(top_rating_progress[i].variance()) << "\n";
 }
 
@@ -675,7 +673,7 @@ void test_position(const FeatureSet& f, Move next_move, Move last_move, const Ra
 
 void test_record(const FeatureSet& f, 
 		 const SimpleState& initial,
-		 const osl::stl::vector<osl::Move>& moves)
+		 const std::vector<osl::Move>& moves)
 {
   NumEffectState state(initial);
 
@@ -700,9 +698,9 @@ void test_record(const FeatureSet& f,
 
 void test_file(const FeatureSet& f, const char *filename)
 {
-  Record rec;
+  RecordMinimal record;
   try {
-    rec = CsaFile(filename).getRecord();
+    record = CsaFileMinimal(filename).load();
   }
   catch (CsaIOError& e) {
     std::cerr << "skip " << filename <<"\n";
@@ -712,7 +710,7 @@ void test_file(const FeatureSet& f, const char *filename)
   catch (...) {
     throw;
   }
-  test_record(f, rec.getInitialState(), rec.getMoves());
+  test_record(f, record.initialState(), record.moves);
 }
 
 /* ------------------------------------------------------------------------- */
