@@ -3,9 +3,8 @@
 #include "osl/rating/featureSet.h"
 #include "osl/rating/ratingEnv.h"
 #include "osl/effect_util/effectUtil.h"
-#include "osl/state/numEffectState.h"
-#include "osl/stl/vector.h"
-#include "osl/record/csa.h"
+#include "osl/numEffectState.h"
+#include "osl/csa.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/kisen.h"
 #include "osl/progress/effect5x3.h"
@@ -20,7 +19,7 @@ namespace po = boost::program_options;
 
 size_t num_kisen, opening_skip, target_limit;
 
-void run(NumEffectState& state, const vector<Move>& moves);
+void run(NumEffectState& state, const std::vector<Move>& moves);
 void show_statistics();
 
 int main(int argc, char **argv)
@@ -74,17 +73,17 @@ int main(int argc, char **argv)
     for (size_t i=0; i<num_kisen; i++) {
       if (i % 16 == 0) 
 	std::cerr << '.';
-      NumEffectState state(kisen_file.getInitialState());
-      const osl::vector<Move> moves = kisen_file.getMoves(i);
+      NumEffectState state(kisen_file.initialState());
+      const std::vector<Move> moves = kisen_file.moves(i);
       run(state, moves);
     }
   }
   for (size_t i=0; i<filenames.size(); ++i) {
     if (i % 16 == 0) 
       std::cerr << '.';
-    CsaFile file(filenames[i]);
-    NumEffectState state(file.getInitialState());
-    const osl::vector<Move> moves = file.getRecord().getMoves();
+    CsaFileMinimal file(filenames[i]);
+    NumEffectState state(file.initialState());
+    const std::vector<Move> moves = file.moves();
     run(state, moves);
   }
   std::cerr << "\n";
@@ -117,7 +116,7 @@ void show(const NumEffectState& state, Move next)
   }
 }
 
-void run(NumEffectState& state, const vector<Move>& moves)
+void run(NumEffectState& state, const std::vector<Move>& moves)
 {
   for (size_t i=0; i<moves.size(); ++i) {
     if (state.inCheck(alt(state.turn())))
@@ -134,8 +133,8 @@ void show_statistics()
 {
   for (size_t i=0; i<top_rated.size(); ++i)
     std::cout << "top " << i 
-	      << " " << top_rated[i].getAverage()*100.0 
-	      << " " << active[i].getAverage()*100.0 
+	      << " " << top_rated[i].average()*100.0 
+	      << " " << active[i].average()*100.0 
 	      << "\n";
 }
 
