@@ -1,26 +1,26 @@
-#include "osl/state/numEffectState.h"
-#include "osl/hash/hashKey.h"
+#include "osl/numEffectState.h"
+#include "osl/hashKey.h"
+#include "osl/record/kisen.h"
+#include "osl/csa.h"
 
 #include <boost/program_options.hpp>
-#include "osl/record/kisen.h"
-#include "osl/record/csa.h"
-#include "osl/stl/hash_map.h"
 
+#include <unordered_map>
 #include <iostream>
 #include <fstream>
 #include <sstream>
 
 struct hash
 {
-  unsigned long operator() (const osl::state::SimpleState &state) const
+  unsigned long operator() (const osl::SimpleState &state) const
   {
-    return osl::hash::HashKey(state).signature();
+    return osl::HashKey(state).signature();
   }
 };
 
 struct equalKey
 {
-  bool operator() (const osl::state::SimpleState &s1, const osl::state::SimpleState &s2) const
+  bool operator() (const osl::SimpleState &s1, const osl::SimpleState &s2) const
   {
     return s1 == s2;
   }
@@ -32,21 +32,21 @@ struct State
   {
   }
   int count;
-  osl::stl::vector<osl::Move> moves;
+  std::vector<osl::Move> moves;
 };
 
 void find_all(const int num_ply, const int threshold,
 	      bool save, const std::vector<std::string> &files)
 {
-  osl::stl::hash_map<osl::state::SimpleState, State, hash, equalKey> states;
+  std::unordered_map<osl::SimpleState, State, hash, equalKey> states;
 
   for (size_t index = 0; index < files.size(); index++)
   {
     osl::record::KisenFile kisen(files[index]);
     for (size_t i = 0; i < kisen.size(); i++)
     {
-      const osl::vector<osl::Move> moves = kisen.getMoves(i);
-      osl::state::NumEffectState state(kisen.getInitialState());
+      const auto moves = kisen.moves(i);
+      osl::NumEffectState state(kisen.initialState());
 
       size_t j = 0;
       for (; j < moves.size() && (int)j < num_ply; j++)
@@ -61,7 +61,7 @@ void find_all(const int num_ply, const int threshold,
       }
       if ((int)j == num_ply)
       {
-	osl::stl::hash_map<osl::state::SimpleState, State, hash, equalKey>::iterator it = states.find(state);
+	auto it = states.find(state);
 	if (it != states.end())
 	{
 	  (it->second.count)++;
@@ -81,9 +81,7 @@ void find_all(const int num_ply, const int threshold,
   }
 
   int index = 1;
-  for (osl::stl::hash_map<osl::state::SimpleState, State, hash, equalKey>::const_iterator it = states.begin();
-       it != states.end();
-       ++it)
+  for (auto it = states.cbegin(); it != states.cend(); ++it)
   {
     if (it->second.count >= threshold)
     {
@@ -99,13 +97,13 @@ void find_all(const int num_ply, const int threshold,
 	output << "PI" << std::endl
 	       << "+" << std::endl;
       }
-      const osl::stl::vector<osl::Move> &moves = it->second.moves;
+      const auto &moves = it->second.moves;
       for (size_t i = 0; i < moves.size(); i++)
       {
-	std::cout << osl::record::csa::show(moves[i]) << " ";
+	std::cout << osl::csa::show(moves[i]) << " ";
 	if (save)
 	{
-	  output << osl::record::csa::show(moves[i]) << std::endl;
+	  output << osl::csa::show(moves[i]) << std::endl;
 	}
       }
       if (save)
