@@ -1,19 +1,18 @@
-#include "osl/state/numEffectState.h"
-#include "osl/hash/hashKey.h"
-
+#include "osl/numEffectState.h"
+#include "osl/hashKey.h"
+#include "osl/record/kisen.h"
+#include "osl/csa.h"
 #include <boost/program_options.hpp>
 #include <boost/format.hpp>
-#include "osl/record/kisen.h"
-#include "osl/record/csa.h"
-#include <osl/stl/hash_set.h>
 
+#include <unordered_set>
 #include <iostream>
 #include <fstream>
 #include <sstream>
 
 struct hash
 {
-  unsigned long operator() (const osl::state::SimpleState &state) const
+  unsigned long operator() (const osl::SimpleState &state) const
   {
     return osl::hash::HashKey(state).signature();
   }
@@ -22,15 +21,15 @@ struct hash
 void find_all(const int num_ply, const int threshold,
 	      bool save, const std::vector<std::string> &files)
 {
-  osl::stl::hash_set<osl::state::SimpleState, hash> states;
+  std::unordered_set<osl::SimpleState, hash> states;
 
   for (size_t index = 0; index < files.size(); index++)
   {
     osl::record::KisenFile kisen(files[index]);
     for (size_t i = 0; i < kisen.size(); i++)
     {
-      const osl::vector<osl::Move> moves = kisen.getMoves(i);
-      osl::state::NumEffectState state(kisen.getInitialState());
+      const auto moves = kisen.moves(i);
+      osl::NumEffectState state(kisen.initialState());
 
       states.insert(state);
       for (size_t j = 0; j < moves.size() && j < static_cast<size_t>(num_ply);
@@ -49,10 +48,7 @@ void find_all(const int num_ply, const int threshold,
   }
 
   int index = 0;
-  for (osl::stl::hash_set<osl::state::SimpleState, hash>::const_iterator it =
-	 states.begin();
-       it != states.end();
-       ++it)
+  for (auto it=states.begin(); it != states.end(); ++it)
   {
     if (save)
     {
