@@ -1,8 +1,6 @@
 #include <boost/program_options.hpp>
 #include <iostream>
-#include "osl/state/simpleState.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csa.h"
 #include "osl/record/record.h"
 #include "osl/record/searchInfo.h"
 
@@ -21,14 +19,14 @@ struct MoveData
 
 void find_bad_moves(bool sente, const std::string &filename)
 {
-  osl::record::csa::CsaFile file(filename);
-  osl::vector<osl::Move> moves;
-  osl::vector<std::string> dummy1;
-  osl::vector<int> time;
-  osl::vector<osl::record::SearchInfo> info;
-  file.getRecord().getMoves(moves, time, dummy1, info);
+  osl::CsaFile file(filename);
+  std::vector<osl::Move> moves;
+  std::vector<std::string> dummy1;
+  std::vector<int> time;
+  std::vector<osl::record::SearchInfo> info;
+  file.load().load(moves, time, dummy1, info);
   int prev_value = 0;
-  osl::vector<MoveData> bad_indices;
+  std::vector<MoveData> bad_indices;
   
   for (size_t i = sente ? 0 : 1; i < info.size(); i += 2)
   {
@@ -48,7 +46,7 @@ void find_bad_moves(bool sente, const std::string &filename)
     }
     prev_value = info[i].value;
   }
-  osl::state::NumEffectState state(file.getInitialState());
+  osl::NumEffectState state(file.initialState());
   for (size_t i = 0, j = 0; i < moves.size() && j < bad_indices.size();
        i++)
   {
@@ -57,10 +55,10 @@ void find_bad_moves(bool sente, const std::string &filename)
       std::cout << state
 		<< "' " <<  i << ": " << info[i].value << " -> "
 		<< info[i+2].value<< std::endl
-		<< osl::record::csa::show(moves[i]) << std::endl
-		<< osl::record::csa::show(moves[i+1]) << std::endl
-		<< osl::record::csa::show(moves[i+2]) << std::endl;
-      osl::stl::vector<osl::Move> &pv_moves = info[i+2].moves;
+		<< osl::csa::show(moves[i]) << std::endl
+		<< osl::csa::show(moves[i+1]) << std::endl
+		<< osl::csa::show(moves[i+2]) << std::endl;
+      std::vector<osl::Move> &pv_moves = info[i+2].moves;
       bool found_pass = false;
       for (size_t k = 0; k < pv_moves.size(); k++)
       {
@@ -76,7 +74,7 @@ void find_bad_moves(bool sente, const std::string &filename)
 	}
 	else
 	{
-	  std::cout << osl::record::csa::show(pv_moves[k]) << std::endl;
+	  std::cout << osl::csa::show(pv_moves[k]) << std::endl;
 	}
       }
       j++;
