@@ -5,12 +5,10 @@
 #include "osl/record/ki2.h"
 #include "osl/record/checkDuplicate.h"
 #include "osl/record/ki2IOError.h"
+#include "osl/csa.h"
 
 #include <boost/algorithm/string/trim.hpp>
-#include <boost/foreach.hpp>
 #include <boost/program_options.hpp>
-#include <boost/lambda/lambda.hpp>
-#include <boost/lambda/bind.hpp>
 #include <iostream>
 #include <fstream>
 #include <string>
@@ -23,19 +21,18 @@
 boost::program_options::variables_map vm;
 osl::record::CheckDuplicate check_duplicate;
 
-using namespace boost::lambda;
-
 void process( const std::string& file_name)
 {
   try {
     bool verbose = false;
     if (vm.count("verbose"))
       verbose = true;
+    bool show_each_move = vm.count("show-moves");
     if (verbose)
-      std::cout << "Processing...  " << file_name << std::endl;
+      std::cerr << "Processing...  " << file_name << std::endl;
     const osl::Ki2File ki2(file_name, verbose);
-    const osl::Record& record = ki2.getRecord();
-    const osl::stl::vector<osl::Move>& moves = record.getMoves();
+    const osl::Record& record = ki2.load();
+    const auto& moves = record.moves();
 
     if (check_duplicate.regist(moves)) {
       std::cerr << "Found a duplicated play: " << file_name << "\n";
@@ -43,13 +40,20 @@ void process( const std::string& file_name)
     }
 
     osl::NumEffectState state;
-    BOOST_FOREACH(const osl::Move& move, moves)
+    for (const osl::Move move: moves)
     {
       if (!state.isValidMove(move, false))
       {
         std::cout << file_name << "\n";
         continue;
       }
+      if (show_each_move)
+	std::cout << move.from().x() << move.from().y()
+		  << ' ' << move.to().x() << move.to().y()
+		  << ' ' << osl::csa::show(move.oldPtype())
+		  << ' ' << osl::csa::show(move.ptype())
+		  << ' ' << osl::csa::show(move.capturePtype())
+		  << std::endl;
       state.makeMove(move);
     }
   } catch (osl::Ki2IOError& err) {
@@ -65,6 +69,7 @@ int main(int argc, char **argv)
   command_line_options.add_options()
     ("input-file", boost::program_options::value< std::vector<std::string> >(),
      "input files in ki2 format (.ki2)")
+    ("show-moves", "show each move")
     ("verbose,v", "Verbose mode")
     ("help,h", "Show this help message");
   boost::program_options::positional_options_description p;
@@ -111,7 +116,7 @@ int main(int argc, char **argv)
   }
 
   // main
-  std::for_each(files.begin(), files.end(), bind(&process, _1));
+  std::for_each(files.begin(), files.end(), [](std::string f){ process(f); });
 
   check_duplicate.print(std::cout);
 
