@@ -1,8 +1,6 @@
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/record/kisen.h"
-#include "osl/record/csaIOError.h"
 
-#include <boost/scoped_ptr.hpp>
 #include <iostream>
 
 void usage (const char *program_name)
@@ -15,11 +13,9 @@ void usage (const char *program_name)
 void check_all(const char*filename, const char *output)
 {
   osl::record::KisenFile kisen(filename);
-  boost::scoped_ptr<std::ofstream> os;
-  boost::scoped_ptr<osl::record::OKisenStream> out;
+  std::unique_ptr<std::ofstream> os;
   if (output) {
     os.reset(new std::ofstream(output));
-    out.reset(new osl::record::OKisenStream(*os));
   }
 
   for (size_t i = 0; i < kisen.size(); i++)
@@ -29,11 +25,11 @@ void check_all(const char*filename, const char *output)
       std::cout << std::endl;
     else
       std::cout << ' ';
-    osl::state::NumEffectState state(kisen.getInitialState());
-    osl::vector<osl::Move> moves;
+    osl::NumEffectState state(kisen.initialState());
+    std::vector<osl::Move> moves;
     size_t j = 0;
     try {
-      moves = kisen.getMoves(i);
+      moves = kisen.moves(i);
       for (; j < moves.size(); j++)
       {
 	const osl::Square opKingSquare 
@@ -48,12 +44,14 @@ void check_all(const char*filename, const char *output)
       }
       moves.resize(j);
     }
-    catch (osl::record::csa::CsaIOError& e) {
+    catch (osl::csa::CsaIOError& e) {
       std::cerr << e.what();
     }
     
-    if (out)
-      out->save(kisen.getInitialState(), moves);
+    if (os) {
+      osl::record::KisenWriter out(*os);
+      out.save({kisen.initialState(), moves});
+    }
   }
 }
 
