@@ -1,20 +1,19 @@
-#include "osl/state/numEffectState.h"
-#include "osl/hash/hashKey.h"
+#include "osl/numEffectState.h"
+#include "osl/hashKey.h"
+#include "osl/csa.h"
+#include "osl/record/kisen.h"
+#include "osl/record/csaRecord.h"
 
 #include <boost/program_options.hpp>
 #include <boost/format.hpp>
-#include <boost/scoped_ptr.hpp>
-#include "osl/record/kisen.h"
-#include "osl/record/csa.h"
-#include "osl/record/csaRecord.h"
-#include "osl/stl/hash_set.h"
 
+#include <unordered_set>
 #include <iostream>
 #include <fstream>
 
 struct hash
 {
-  unsigned long operator() (const osl::state::SimpleState &state) const
+  unsigned long operator() (const osl::SimpleState &state) const
   {
     return osl::hash::HashKey(state).signature();
   }
@@ -25,7 +24,7 @@ class StatePredicate
 public:
   StatePredicate(const std::vector<std::string> &filenames) { }
   virtual ~StatePredicate() { }
-  virtual bool match (const osl::state::NumEffectState &state) const
+  virtual bool match (const osl::NumEffectState &state) const
   {
     return false;
   }
@@ -40,12 +39,12 @@ public:
   {
     for (size_t i = 0; i < filenames.size(); ++i)
     {
-      osl::record::csa::CsaFile file(filenames[i]);
-      states.insert(file.getInitialState());
+      osl::CsaFile file(filenames[i]);
+      states.insert(file.initialState());
     }
   }
   ~CsaPredicate() { }
-  bool match (const osl::state::NumEffectState &state) const
+  bool match (const osl::NumEffectState &state) const
   {
     return states.find(state) != states.end();
   }
@@ -54,13 +53,13 @@ public:
     return !states.empty();
   }
 private:
-  osl::stl::hash_set<osl::state::SimpleState, hash> states;
+  std::unordered_set<osl::SimpleState, hash> states;
 };
 
 class PieceStandPredicate : public StatePredicate
 {
 private:
-  bool match(const osl::state::NumEffectState &state, osl::Player player) const
+  bool match(const osl::NumEffectState &state, osl::Player player) const
   {
     return state.countPiecesOnStand<osl::ROOK>(player) == 1 &&
       state.countPiecesOnStand<osl::BISHOP>(player) == 1 &&
@@ -72,7 +71,7 @@ private:
 public:
   PieceStandPredicate(const std::vector<std::string> &filenames)
     : StatePredicate(filenames) { }
-  bool match (const osl::state::NumEffectState &state) const
+  bool match (const osl::NumEffectState &state) const
   {
     return match(state, osl::BLACK) || match(state, osl::WHITE);
   }
@@ -127,7 +126,7 @@ int main(int argc, char **argv)
   if (vm.count("input-file"))
     files = vm["input-file"].as< std::vector<std::string> >();
 
-  boost::scoped_ptr<StatePredicate> predicate;
+  std::unique_ptr<StatePredicate> predicate;
   if (predicate_name == "csa")
   {
     predicate.reset(new CsaPredicate(files));
@@ -149,8 +148,8 @@ int main(int argc, char **argv)
   osl::record::KisenFile kisen(kisen_filename);
   for (size_t i = 0; i < kisen.size(); i++)
   {
-    const osl::vector<osl::Move> moves = kisen.getMoves(i);
-    osl::state::NumEffectState state = kisen.getInitialState();
+    const auto moves = kisen.moves(i);
+    auto state = kisen.initialState();
     for (size_t j = 0; j < moves.size(); j++)
     {
       const osl::Square opKingSquare 
