@@ -2,8 +2,7 @@
  */
 #include "osl/record/kakinoki.h"
 #include "osl/record/ki2.h"
-#include "osl/record/csa.h"
-#include "osl/record/record.h"
+#include "osl/csa.h"
 #include <boost/algorithm/string/predicate.hpp>
 #include <iostream>
 #include <sstream>
@@ -11,32 +10,30 @@
 using namespace osl;
 void convert(const char *filename)
 {
-  vector<Move> moves;
-  vector<int> time;
-  vector<std::string> comment;
-  vector<record::SearchInfo> move_comment;
+  std::vector<Move> moves;
+  std::vector<int> time;
   Record record;
   NumEffectState state;
   if (boost::algorithm::iends_with(filename, ".ki2")) {
     Ki2File file(filename);
-    record = file.getRecord();
-    state = file.getInitialState();
+    record = file.load();
+    state = file.initialState();
   }
   else {
     KakinokiFile file(filename);
-    record = file.getRecord();
-    state = file.getInitialState();
+    record = file.load();
+    state = file.initialState();
   }
-  std::cout << "N+" << record.getPlayer(BLACK) << std::endl;
-  std::cout << "N-" << record.getPlayer(WHITE) << std::endl;
-  record.getMoves(moves, time, comment, move_comment);
+  std::cout << "N+" << record.player[BLACK] << std::endl;
+  std::cout << "N-" << record.player[WHITE] << std::endl;
+  record.load(moves, time);
   std::cout << state;
   for (size_t i=0; i<moves.size(); ++i) 
   {
-    std::cout << record::csa::show(moves[i]) << std::endl;
-    if (i < comment.size()) 
+    std::cout << csa::show(moves[i]) << std::endl;
+    if (i < record.comments.size()) 
     {
-      std::istringstream is(comment[i]);
+      std::istringstream is(record.comments[i]);
       std::string line;
       while (std::getline(is, line)) 
 	std::cout << "'* " << line << std::endl;
