@@ -9,9 +9,9 @@ int main(int argc, char **argv) {
     return 1;
   std::string filename = argv[1];
   const osl::KakinokiFile file(filename);
-  const osl::record::Record record = file.getRecord();
-  osl::vector<osl::Move> moves = record.getMoves();
-  osl::NumEffectState state = record.getInitialState();
+  const auto record = file.load();
+  auto moves = record.moves();
+  auto state = record.initialState();
   for (size_t i=0; i<moves.size(); ++i) {
     osl::NumEffectState next(state);
     next.makeMove(moves[i]);
