@@ -1,4 +1,4 @@
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/record/kisen.h"
 #include "osl/record/csaRecord.h"
 
@@ -19,12 +19,12 @@ void convert(const char*kisen_filename, const char *csa_filename, size_t i)
 
   if (i < kisen.size())
   {
-    osl::state::NumEffectState state = kisen.getInitialState();
+    osl::NumEffectState state = kisen.initialState();
     ofs << state;
-    const osl::stl::vector<osl::Move> moves = kisen.getMoves(i);
+    const auto& moves = kisen.moves(i);
     for (size_t j = 0; j < moves.size(); ++j)
     {
-      ofs << osl::record::csa::show(moves[j]) << std::endl;
+      ofs << osl::csa::show(moves[j]) << std::endl;
     }
   }
   else
