@@ -2,10 +2,9 @@
  * 
  */
 #include "osl/record/csaRecord.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/effect_util/effectUtil.h"
 
-#include <boost/foreach.hpp>
 #include <fstream>
 #include <iostream>
 #include <cstdlib>
@@ -31,12 +30,12 @@ int main(int argc, char **argv)
     //次に CSAファイルを処理
     for (int i=1; i<argc; ++i) {
       CsaFile file(argv [i]);
-      const vector<Move> moves=file.getRecord().getMoves();
-      NumEffectState state((SimpleState(HIRATE)));
-      BOOST_FOREACH(Move m, moves)
+      const auto moves=file.load().moves();
+      NumEffectState state;
+      for(Move m: moves)
 	state.makeMove(m);
       std::string new_name = std::string("tmp/")+argv[i];
-      std::ofstream os(new_name.c_str());
+      std::ofstream os(new_name);
       os << state;
     }
   }
