@@ -12,7 +12,7 @@ int main(int argc, char **argv)
   for (int i=1; i<argc; ++i) {
     KisenIpxFile ipx(argv[i]);
     for (size_t j=0; j<ipx.size(); ++j) {
-      const int result = ipx.getResult(j);
+      const int result = ipx.result(j);
       results[result] = results.at(result) + 1; 
     }
   }
