@@ -2,7 +2,6 @@
  */
 #include "osl/effect_util/effectUtil.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csa.h"
 #include <iostream>
 #include <cstdio>
 using namespace osl;
@@ -38,9 +37,9 @@ int main(int argc, char **argv)
   for (int i=0; i<argc; ++i)
   {
     CsaFile file(argv [i]);
-    NumEffectState state(file.getInitialState());
+    NumEffectState state(file.initialState());
     PieceVector v;
-    EffectUtil::findEffect(BLACK, state, target, v);
+    state.findEffect(BLACK, target, v);
     std::cout << v;
   }
 }
