@@ -2,7 +2,7 @@
  */
 #include "osl/repetitionCounter.h"
 #include "osl/record/csaRecord.h"
-#include "osl/record/csa.h"
+#include "osl/csa.h"
 #include <iostream>
 #include <cstdio>
 
@@ -12,13 +12,13 @@ void usage(const char *program_name)
 
 using namespace osl;
 
-void processRecord(osl::vector<Move> const& moves)
+void processRecord(std::vector<Move> const& moves)
 {
-  NumEffectState state((SimpleState(HIRATE)));
+  NumEffectState state;
   RepetitionCounter counter(state);
   for (size_t i=0; i<moves.size (); ++i)
   {
-    std::cout << i+1 << " " << record::csa::show(moves[i]) << std::endl;
+    std::cout << i+1 << " " << csa::show(moves[i]) << std::endl;
     std::cout << counter.isSennichite(state, moves[i]) << std::endl;
     std::cout << "(" 
 	      << counter.isAlmostSennichite(HashKey(state).newHashWithMove(moves[i]))
@@ -69,9 +69,8 @@ int main(int argc, char **argv)
   //次に CSAファイルを処理
   for (int i=0; i<argc; ++i)
   {
-    CsaFile file(argv [i]);
-    const vector<Move> moves=file.getRecord().getMoves();
-
+    CsaFileMinimal file(argv [i]);
+    const auto moves=file.load().moves;
     processRecord(moves);
   }
 }
