@@ -3,11 +3,10 @@
  */
 
 #include "osl/search/sortCaptureMoves.h"
-#include "osl/state/numEffectState.h"
+#include "osl/numEffectState.h"
 #include "osl/move_generator/allMoves.h"
 #include "osl/effect_util/effectUtil.h"
 #include "osl/record/csaRecord.h"
-#include "osl/container/moveVector.h"
 
 #include <iostream>
 #include <cstdlib>
@@ -47,11 +46,11 @@ int main(int argc, char **argv)
       
     for (int i=0; i<argc; ++i) {
       CsaFile file(argv [i]);
-      const Record record = file.getRecord();
-      NumEffectState state(record.getInitialState());
+      const Record record = file.load();
+      NumEffectState state(record.initialState());
 
       MoveVector moves;
-      GenerateAllMoves::generate(state.turn(), state, moves);
+      state.generateAllUnsafe(moves);
       search::SortCaptureMoves::sortByTakeBack(state, moves);
       std::cout << state << moves << "\n";
     }
